import { useEffect } from "react";



function CountDown({ timeLeft, setTimeLeft, isTimerRunning }: { timeLeft: number; setTimeLeft: React.Dispatch<React.SetStateAction<number>>, isTimerRunning: boolean }) {
	useEffect(() => {
		let intervalId: NodeJS.Timeout;

		if (isTimerRunning && timeLeft > 0) {
			intervalId = setInterval(() => {
				setTimeLeft((prevTime: any) => prevTime - 1);
			}, 1000);
		}

		return () => {
			if (intervalId) {
				clearInterval(intervalId);
			}
		};
	}, [timeLeft, isTimerRunning]);

	const formatTime = (seconds: number) => {
		const minutes = Math.floor(seconds / 60);
		const remainingSeconds = seconds % 60;
		return `${minutes}:${remainingSeconds < 10 ? "0" : ""}${remainingSeconds}`;
	};

	return (<div className="text-center">
		الوقت المتبقي <span><b>{formatTime(timeLeft)}</b></span> دقيقة
	</div>);
}

export default CountDown;